#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.1
visibility:           public
id:                   streaming-commons-0.2.2.1-ECkYijsiekA4Fkarkvgqnu
key:                  streaming-commons-0.2.2.1-ECkYijsiekA4Fkarkvgqnu
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  d14c3652b28064f8e9d83231e14f1456
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

hidden-modules:
    Data.Text.Internal.Unsafe.Char Data.Text.Internal.Unsafe.Shift
    Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Encoding.Utf16
    Data.Text.Internal.Encoding.Utf32

import-dirs:          /usr/lib/ghc-8.10.5/site-local/streaming-commons-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/streaming-commons-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/streaming-commons-0.2.2.1
hs-libraries:         HSstreaming-commons-0.2.2.1-ECkYijsiekA4Fkarkvgqnu
depends:
    array-0.5.4.0 async-2.2.3-6QbaQgrhqs02Gm74dJYuzp base-4.14.2.0
    bytestring-0.10.12.0 directory-1.3.6.0
    network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd process-1.6.9.0
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub stm-2.5.0.1 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.2.3-iLt2uLes3HGCCNqRD7eNI

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

